@@ -178,14 +178,13 @@ class Probe:
             result: Optional[dict],
             error: Optional[dict],
             ts: float):
-        assert (result is None) ^ (error is None)
         asset_id, _ = path
         check_data = {
             'result': result,
             'error': error,
             'framework': {
                 'duration': time.time() - ts,
-                'timestamp': ts,
+                'timestamp': int(ts),
             }
         }
         pkg = Package.make(
@@ -286,17 +285,17 @@ class Probe:
 
     async def _run_check_loop(self, path: tuple):
         asset_id, _ = path
-        (asset_name, check_name), config = self._checks_config[path]
+        (asset_name, check_key), config = self._checks_config[path]
         interval = config.get('_interval')
-        fun = self._checks_funs[check_name]
-        asset = Asset(asset_id, asset_name, check_name)
+        fun = self._checks_funs[check_key]
+        asset = Asset(asset_id, asset_name, check_key)
 
         my_task = self._checks[path]
 
         assert isinstance(interval, int) and interval > 0
 
         ts = time.time()
-        ts_next = int(ts + random.random() * interval) + 1
+        ts_next = (ts + random.random() * interval) + 1.0
 
         while True:
             if ts > ts_next:
@@ -317,8 +316,8 @@ class Probe:
             interval = config.get('_interval')
             timeout = 0.8 * interval
             if asset.name != asset_name:
-                # asset_id and check_name are truly immutable, name is not
-                asset = Asset(asset_id, asset_name, check_name)
+                # asset_id and check_key are truly immutable, name is not
+                asset = Asset(asset_id, asset_name, check_key)
 
             logging.debug(f'run check; {asset}')
 
@@ -360,6 +359,10 @@ class Probe:
                 logging.warning(
                     'incomplete result; '
                     f'{asset} error: `{e}` severity: {e.severity}')
+                logging.error(path)
+                logging.error(e.result)
+                logging.error(e.to_dict())
+                logging.error(ts)
                 self.send(path, e.result, e.to_dict(), ts)
 
             except CheckException as e:
